@@ -9,7 +9,12 @@ from enum import IntFlag
 from math import isnan
 from typing import Any, Callable
 
-from rapidfuzz._feature_detector import AVX2, supports
+from rapidfuzz._feature_detector import AVX2, SSE2, supports
+
+try:
+    from pandas import NA as pandas_NA
+except BaseException:
+    pandas_NA = None
 
 
 class ScorerFlag(IntFlag):
@@ -51,7 +56,7 @@ def _get_scorer_flags_normalized_similarity(**_kwargs: Any) -> dict[str, Any]:
 
 
 def is_none(s: Any) -> bool:
-    if s is None:
+    if s is None or s is pandas_NA:
         return True
 
     if isinstance(s, float) and isnan(s):
@@ -84,6 +89,10 @@ def vectorized_import(name: str) -> tuple[Any, list[Any]]:
         module = optional_import_module(name + "_avx2")
         if module is not None:
             return module
+    if supports(SSE2):
+        module = optional_import_module(name + "_sse2")
+        if module is not None:
+            return module
 
     return importlib.import_module(name)
 
