@@ -4,8 +4,8 @@
 from __future__ import annotations
 
 import heapq
+import numbers
 from contextlib import suppress
-from math import isnan
 from typing import (
     Any,
     Callable,
@@ -17,7 +17,7 @@ from typing import (
     overload,
 )
 
-from rapidfuzz._utils import ScorerFlag
+from rapidfuzz._utils import ScorerFlag, is_none
 from rapidfuzz.fuzz import WRatio, ratio
 
 __all__ = ["extract", "extract_iter", "extractOne", "cdist"]
@@ -31,16 +31,6 @@ def _get_scorer_flags_py(scorer: Any, scorer_kwargs: dict[str, Any]) -> tuple[in
     return (0, 100)
 
 
-def _is_none(s: Any) -> bool:
-    if s is None:
-        return True
-
-    if isinstance(s, float) and isnan(s):
-        return True
-
-    return False
-
-
 @overload
 def extract_iter(
     query: Sequence[Hashable] | None,
@@ -100,9 +90,9 @@ def extract_iter(
         comparing them. Default is None, which deactivates this behaviour.
     score_cutoff : Any, optional
         Optional argument for a score threshold. When an edit distance is used this represents the maximum
-        edit distance and matches with a `distance <= score_cutoff` are ignored. When a
+        edit distance and matches with a `distance > score_cutoff` are ignored. When a
         normalized edit distance is used this represents the minimal similarity
-        and matches with a `similarity >= score_cutoff` are ignored. Default is None, which deactivates this behaviour.
+        and matches with a `similarity < score_cutoff` are ignored. Default is None, which deactivates this behaviour.
     score_hint : Any, optional
         Optional argument for an expected score to be passed to the scorer.
         This is used to select a faster implementation. Default is None,
@@ -122,7 +112,7 @@ def extract_iter(
         * The second value represents the similarity calculated by the scorer. This can be:
 
           * An edit distance (distance is 0 for a perfect match and > 0 for non perfect matches).
-            In this case only choices which have a `distance <= max` are yielded.
+            In this case only choices which have a `distance <= score_cutoff` are yielded.
             An example of a scorer with this behavior is `Levenshtein.distance`.
           * A normalized edit distance (similarity is a score between 0 and 100, with 100 being a perfect match).
             In this case only choices which have a `similarity >= score_cutoff` are yielded.
@@ -141,7 +131,7 @@ def extract_iter(
     worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
-    if _is_none(query):
+    if is_none(query):
         return
 
     if score_cutoff is None:
@@ -154,7 +144,7 @@ def extract_iter(
     choices_iter: Iterable[tuple[Any, Sequence[Hashable] | None]]
     choices_iter = choices.items() if hasattr(choices, "items") else enumerate(choices)  # type: ignore[union-attr]
     for key, choice in choices_iter:
-        if _is_none(choice):
+        if is_none(choice):
             continue
 
         if processor is None:
@@ -235,9 +225,9 @@ def extractOne(
         comparing them. Default is None, which deactivates this behaviour.
     score_cutoff : Any, optional
         Optional argument for a score threshold. When an edit distance is used this represents the maximum
-        edit distance and matches with a `distance <= score_cutoff` are ignored. When a
+        edit distance and matches with a `distance > score_cutoff` are ignored. When a
         normalized edit distance is used this represents the minimal similarity
-        and matches with a `similarity >= score_cutoff` are ignored. Default is None, which deactivates this behaviour.
+        and matches with a `similarity < score_cutoff` are ignored. Default is None, which deactivates this behaviour.
     score_hint : Any, optional
         Optional argument for an expected score to be passed to the scorer.
         This is used to select a faster implementation. Default is None,
@@ -304,11 +294,11 @@ def extractOne(
 
     It is possible to specify a processor function which is used to preprocess the strings before comparing them.
 
-    >>> extractOne("abcd", ["abdD"], scorer=ratio)
+    >>> extractOne("abcd", ["abcD"], scorer=ratio)
     ("abcD", 75.0, 0)
-    >>> extractOne("abcd", ["abdD"], scorer=ratio, processor=utils.default_process)
+    >>> extractOne("abcd", ["abcD"], scorer=ratio, processor=utils.default_process)
     ("abcD", 100.0, 0)
-    >>> extractOne("abcd", ["abdD"], scorer=ratio, processor=lambda s: s.upper())
+    >>> extractOne("abcd", ["abcD"], scorer=ratio, processor=lambda s: s.upper())
     ("abcD", 100.0, 0)
 
     When only results with a similarity above a certain threshold are relevant, the parameter score_cutoff can be
@@ -334,7 +324,7 @@ def extractOne(
     worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
-    if _is_none(query):
+    if is_none(query):
         return None
 
     if score_cutoff is None:
@@ -349,7 +339,7 @@ def extractOne(
     choices_iter: Iterable[tuple[Any, Sequence[Hashable] | None]]
     choices_iter = choices.items() if hasattr(choices, "items") else enumerate(choices)  # type: ignore[union-attr]
     for key, choice in choices_iter:
-        if _is_none(choice):
+        if is_none(choice):
             continue
 
         if processor is None:
@@ -384,7 +374,7 @@ def extract(
     *,
     scorer: Callable[..., int | float] = WRatio,
     processor: Callable[..., Sequence[Hashable]] | None = None,
-    limit: int | None = None,
+    limit: int | None = 5,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
     scorer_kwargs: dict[str, Any] | None = None,
@@ -399,7 +389,7 @@ def extract(
     *,
     scorer: Callable[..., int | float] = WRatio,
     processor: Callable[..., Sequence[Hashable]] | None = None,
-    limit: int | None = None,
+    limit: int | None = 5,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
     scorer_kwargs: dict[str, Any] | None = None,
@@ -438,13 +428,14 @@ def extract(
     processor : Callable, optional
         Optional callable that is used to preprocess the strings before
         comparing them. Default is None, which deactivates this behaviour.
-    limit : int
-        maximum amount of results to return
+    limit : int, optional
+        maximum amount of results to return. None can be passed to disable this behavior.
+        Default is 5.
     score_cutoff : Any, optional
         Optional argument for a score threshold. When an edit distance is used this represents the maximum
-        edit distance and matches with a `distance <= score_cutoff` are ignored. When a
+        edit distance and matches with a `distance > score_cutoff` are ignored. When a
         normalized edit distance is used this represents the minimal similarity
-        and matches with a `similarity >= score_cutoff` are ignored. Default is None, which deactivates this behaviour.
+        and matches with a `similarity < score_cutoff` are ignored. Default is None, which deactivates this behaviour.
     score_hint : Any, optional
         Optional argument for an expected score to be passed to the scorer.
         This is used to select a faster implementation. Default is None,
@@ -464,7 +455,7 @@ def extract(
         * The second value represents the similarity calculated by the scorer. This can be:
 
           * An edit distance (distance is 0 for a perfect match and > 0 for non perfect matches).
-            In this case only choices which have a `distance <= max` are returned.
+            In this case only choices which have a `distance <= score_cutoff` are returned.
             An example of a scorer with this behavior is `Levenshtein.distance`.
           * A normalized edit distance (similarity is a score between 0 and 100, with 100 being a perfect match).
             In this case only choices which have a `similarity >= score_cutoff` are returned.
@@ -477,7 +468,7 @@ def extract(
           * The `index of choice` when choices is a simple iterable like a list
           * The `key of choice` when choices is a mapping like a dict, or a pandas Series
 
-        The list is sorted by `score_cutoff` or `max` depending on the scorer used. The first element in the list
+        The list is sorted by similarity or distance depending on the scorer used. The first element in the list
         has the `highest similarity`/`smallest distance`.
 
     """
@@ -485,6 +476,20 @@ def extract(
     worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
+    if limit == 1:
+        res = extractOne(
+            query,
+            choices,
+            processor=processor,
+            scorer=scorer,
+            score_cutoff=score_cutoff,
+            score_hint=score_hint,
+            scorer_kwargs=scorer_kwargs,
+        )
+        if res is None:
+            return []
+        return [res]
+
     result_iter = extract_iter(
         query,
         choices,
@@ -545,6 +550,7 @@ def cdist(
     processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
+    score_multiplier: int | float = 1,
     dtype: np.dtype | None = None,
     workers: int = 1,
     scorer_kwargs: dict[str, Any] | None = None,
@@ -560,13 +566,9 @@ def cdist(
         list of all strings the query should be compared
     scorer : Callable, optional
         Optional callable that is used to calculate the matching score between
-        the query and each choice. This can be:
-
-        - a scorer using the RapidFuzz C-API like the builtin scorers in RapidFuzz,
-          which can return a distance or similarity between two strings. Further details can be found here.
-        - a Python function which returns a similarity between two strings in the range 0-100. This is not
-          recommended, since it is far slower than a scorer using the RapidFuzz C-API.
-
+        the query and each choice. This can be any of the scorers included in RapidFuzz
+        (both scorers that calculate the edit distance or the normalized edit distance), or
+        a custom function, which returns a normalized edit distance.
         fuzz.ratio is used by default.
     processor : Callable, optional
         Optional callable that is used to preprocess the strings before
@@ -578,6 +580,11 @@ def cdist(
         Optional argument for an expected score to be passed to the scorer.
         This is used to select a faster implementation. Default is None,
         which deactivates this behaviour.
+    score_multiplier: Any, optional
+        Optional argument to multiply the calculated score with. This is applied as the final step,
+        so e.g. score_cutoff is applied on the unmodified score. This is mostly useful to map from
+        a floating point range to an integer to reduce the memory usage. Default is 1,
+        which deactivates this behaviour.
     dtype : data-type, optional
         The desired data-type for the result array.Depending on the scorer type the following
         dtypes are supported:
@@ -614,27 +621,48 @@ def cdist(
     if processor is None:
         proc_choices = list(choices)
     else:
-        proc_choices = [x if _is_none(x) else processor(x) for x in choices]
+        proc_choices = [x if is_none(x) else processor(x) for x in choices]
 
     if queries is choices and _is_symmetric(scorer, scorer_kwargs):
         for i, query in enumerate(proc_choices):
-            results[i, i] = scorer(query, query, score_cutoff=score_cutoff, **scorer_kwargs)
+            score = scorer(query, query, score_cutoff=score_cutoff, **scorer_kwargs) * score_multiplier
+
+            if issubclass(dtype, numbers.Integral):
+                score = round(score)
+
+            results[i, i] = score
             for j in range(i + 1, len(proc_choices)):
-                results[i, j] = results[j, i] = scorer(
-                    query,
-                    proc_choices[j],
-                    score_cutoff=score_cutoff,
-                    **scorer_kwargs,
-                )
-    else:
-        for i, query in enumerate(queries):
-            proc_query = processor(query) if (processor and not _is_none(query)) else query
-            for j, choice in enumerate(proc_choices):
-                results[i, j] = scorer(
-                    proc_query,
-                    choice,
-                    score_cutoff=score_cutoff,
-                    **scorer_kwargs,
+                score = (
+                    scorer(
+                        query,
+                        proc_choices[j],
+                        score_cutoff=score_cutoff,
+                        **scorer_kwargs,
+                    )
+                    * score_multiplier
                 )
 
+                if issubclass(dtype, numbers.Integral):
+                    score = round(score)
+
+                results[i, j] = results[j, i] = score
+    else:
+        for i, query in enumerate(queries):
+            proc_query = processor(query) if (processor and not is_none(query)) else query
+            for j, choice in enumerate(proc_choices):
+                score = (
+                    scorer(
+                        proc_query,
+                        choice,
+                        score_cutoff=score_cutoff,
+                        **scorer_kwargs,
+                    )
+                    * score_multiplier
+                )
+
+                if issubclass(dtype, numbers.Integral):
+                    score = round(score)
+
+                results[i, j] = score
+
     return results
