@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import pytest
 
+from rapidfuzz import utils_cpp, utils_py
 from rapidfuzz.distance import metrics_cpp, metrics_py
 from tests.distance.common import Hamming
 
@@ -45,6 +46,12 @@ def test_disable_padding():
     with pytest.raises(ValueError, match="Sequences are not the same length."):
         Hamming.distance("aaaa", "aaaaa", pad=False)
 
+    with pytest.raises(ValueError, match="Sequences are not the same length."):
+        metrics_cpp.hamming_editops("aaaa", "aaaaa", pad=False)
+
+    with pytest.raises(ValueError, match="Sequences are not the same length."):
+        metrics_py.hamming_editops("aaaa", "aaaaa", pad=False)
+
 
 def test_score_cutoff():
     """
@@ -80,3 +87,8 @@ def test_Editops():
     ops = hamming_editops("aaabaaa", "abbaaabba")
     assert ops.src_len == 7
     assert ops.dest_len == 9
+
+
+def testCaseInsensitive():
+    assert Hamming.distance("new york mets", "new YORK mets", processor=utils_cpp.default_process) == 0
+    assert Hamming.distance("new york mets", "new YORK mets", processor=utils_py.default_process) == 0
